@@ -35,7 +35,7 @@ class EventTypeSpec(ctypes.Structure):
 
 
 def _ctypes_setup():
-    carbon = ctypes.CDLL("/System/Library/Carbon.framework/Carbon")
+    carbon = ctypes.CDLL("/System/Library/Frameworks/Carbon.framework/Carbon")
 
     # timer_func = ctypes.CFUNCTYPE(
     #        None, ctypes.c_void_p, ctypes.c_long)
