@@ -2,7 +2,7 @@ def _disable_linecache():
     import linecache
 
     def fake_getline(*args, **kwargs):
-        return ''
+        return ""
 
     linecache.orig_getline = linecache.getline
     linecache.getline = fake_getline
