@@ -1,4 +1,5 @@
 import sys
+
 from modulegraph.modulegraph import MissingModule
 
 
@@ -8,8 +9,8 @@ def check(cmd, mf):
 
     # ftplib has an optional dependency on an external (and likely
     # non-existing) SOCKS module.
-    f = mf.findNode('ftplib')
-    m = mf.findNode('SOCKS')
+    f = mf.findNode("ftplib")
+    m = mf.findNode("SOCKS")
     if m is not None and f is not None and isinstance(m, MissingModule):
         mf.removeReference(f, m)
 
