@@ -9,13 +9,14 @@ The problem with SIP is that all inter-module depedencies (for example from
 PyQt4.Qt to PyQt4.QtCore) are handled in C code and therefore cannot be
 detected by the python code in py2app).
 """
+
 from __future__ import absolute_import
 
 import glob
 import os
 import sys
 
-import pkg_resources
+from py2app.util import resource_filename
 
 
 class Sip(object):
@@ -122,7 +123,7 @@ class Sip(object):
                 print("WARNING: ImportError in sip recipe ignored: %s" % (exc,))
 
         if mf.findNode("PyQt4") is not None or mf.findNode("PyQt5") is not None:
-            resources = [pkg_resources.resource_filename("py2app", "recipes/qt.conf")]
+            resources = [resource_filename("py2app", "recipes/qt.conf")]
 
             for item in cmd.qt_plugins:
                 if "/" not in item:
