@@ -7,14 +7,33 @@ import os
 import stat
 import subprocess
 import sys
+import textwrap
 import time
 import warnings
 import zipfile
-import textwrap
 from distutils import log
 
 import macholib.util
-import pkg_resources
+
+try:
+    from importlib.metadata import entry_points
+    from importlib.resources import _files
+    import pathlib
+
+    def resource_filename(pkg, path):
+        p = _files(pkg) / path
+        assert isinstance(p, pathlib.Path)
+        return str(p)
+
+
+except ImportError:
+    import pkg_resources
+
+    def entry_points(group):
+        return list(pkg_resources.iter_entry_points("py2app.converter"))
+
+    from pkg_resources import resource_filename  # noqa: F401
+
 from macholib.util import is_platform_file
 from modulegraph import zipio
 from modulegraph.find_modules import PY_SUFFIXES
@@ -34,22 +53,30 @@ except ImportError:
 
 
 def os_path_islink(path):
-    warnings.warn("Use zipio.islink instead of os_path_islink", DeprecationWarning)
+    warnings.warn(
+        "Use zipio.islink instead of os_path_islink", DeprecationWarning, stacklevel=2
+    )
     return zipio.islink(path)
 
 
 def os_path_isdir(path):
-    warnings.warn("Use zipio.isdir instead of os_path_isdir", DeprecationWarning)
+    warnings.warn(
+        "Use zipio.isdir instead of os_path_isdir", DeprecationWarning, stacklevel=2
+    )
     return zipio.islink(path)
 
 
 def os_readlink(path):
-    warnings.warn("Use zipio.readlink instead of os_readlink", DeprecationWarning)
+    warnings.warn(
+        "Use zipio.readlink instead of os_readlink", DeprecationWarning, stacklevel=2
+    )
     return zipio.islink(path)
 
 
 def get_zip_data(path_to_zip, path_in_zip):
-    warnings.warn("Use zipio.open instead of get_zip_data", DeprecationWarning)
+    warnings.warn(
+        "Use zipio.open instead of get_zip_data", DeprecationWarning, stacklevel=2
+    )
     zf = zipfile.ZipFile(path_to_zip)
     return zf.read(path_in_zip)
 
@@ -59,7 +86,7 @@ def path_to_zip(path):
     Returns (pathtozip, pathinzip). If path isn't in a zipfile pathtozip
     will be None
     """
-    warnings.warn("Don't use this function", DeprecationWarning)
+    warnings.warn("Don't use this function", DeprecationWarning, stacklevel=2)
     zf = zipfile.ZipFile(path_to_zip)
     orig_path = path
     from distutils.errors import DistutilsFileError
@@ -95,7 +122,7 @@ def get_mtime(path, mustExist=True):
     """
     Get mtime of a path, even if it is inside a zipfile
     """
-    warnings.warn("Don't use this function", DeprecationWarning)
+    warnings.warn("Don't use this function", DeprecationWarning, stacklevel=2)
     try:
         return zipio.getmtime(path)
 
@@ -114,7 +141,7 @@ gConverterTab = {}
 
 def find_converter(source):
     if not gConverterTab:
-        for ep in pkg_resources.iter_entry_points("py2app.converter"):
+        for ep in entry_points(group="py2app.converter"):
             function = ep.load()
             if not hasattr(function, "py2app_suffix"):
                 print(
@@ -362,9 +389,9 @@ class FileSet(object):
         return res
 
 
-
 if imp is None:
-        LOADER = textwrap.dedent("""\
+    LOADER = textwrap.dedent(
+        """\
                 def __load():
                     import os, sys, importlib.machinery, importlib._bootstrap
                     ext = %r
@@ -373,7 +400,8 @@ if imp is None:
                             continue
                         ext_path = os.path.join(path, ext)
                         if os.path.exists(ext_path):
-                            loader = importlib.machinery.ExtensionFileLoader(__name__, ext_path)
+                            loader = importlib.machinery.ExtensionFileLoader(
+                                 __name__, ext_path)
                             spec = importlib.machinery.ModuleSpec(
                                 name=__name__, loader=loader, origin=ext_path)
                             importlib._bootstrap._load(spec)
@@ -382,10 +410,12 @@ if imp is None:
                         raise ImportError(repr(ext) + " not found")
                 __load()
                 del __load
-                """)
+                """
+    )
 
 else:
-        LOADER = textwrap.dedent("""\
+    LOADER = textwrap.dedent(
+        """\
                 def __load():
                     import os, sys, imp
                     ext = %r
@@ -400,7 +430,8 @@ else:
                         raise ImportError(repr(ext) + " not found")
                 __load()
                 del __load
-                """)
+                """
+    )
 
 
 def make_loader(fn):
@@ -423,7 +454,7 @@ def byte_compile(
         if verbose:
             print("writing byte-compilation script")
         if not dry_run:
-            kwargs = { "encoding": "utf-8" } if sys.version_info[0] == 3 else {}
+            kwargs = {"encoding": "utf-8"} if sys.version_info[0] == 3 else {}
             with NamedTemporaryFile(
                 suffix=".py", delete=False, mode="w", **kwargs
             ) as script:
@@ -623,7 +654,6 @@ def copy_tree(
     dry_run=0,
     condition=None,
 ):
-
     """
     Copy an entire directory tree 'src' to a new location 'dst'.  Both
     'src' and 'dst' must be directory names.  If 'src' is not a
