@@ -1,10 +1,20 @@
 import sys
 from email import *
 
+def _fetch_path(gl, name):
+    parts = name.split('.')
+    gl = gl[parts[0]]
+
+    for n in parts[1:]:
+        gl = getattr(gl, n)
+    return gl
+
+
 def import_module(name):
     try:
-        exec ("import %s"%(name,))
-        m = eval(name)
+        gl = {}
+        exec ("import %s"%(name,), gl, gl)
+        m = _fetch_name(gl, name)
     except ImportError:
         print ("* import failed")
 
