@@ -2,8 +2,10 @@ from setuptools import setup, Command, Extension
 from distutils.command import build_ext as mod_build_ext
 
 from distutils.sysconfig import get_config_var
+from distutils.version import LooseVersion
 import subprocess
 import os
+import glob
 import shutil
 import platform
 import shlex
@@ -18,7 +20,7 @@ class sharedlib (Command):
     def finalize_options(self): pass
 
     def run(self):
-        if platform.mac_ver()[0] < '10.7.':
+        if LooseVersion(platform.mac_ver()[0]) < LooseVersion('10.7'):
             cc = [get_config_var('CC')]
             env = dict(os.environ)
             env['MACOSX_DEPLOYMENT_TARGET'] = get_config_var('MACOSX_DEPLOYMENT_TARGET')
@@ -77,11 +79,14 @@ class my_build_ext (mod_build_ext.build_ext):
 
         mod_build_ext.build_ext.run(self)
 
+        fns = glob.glob('square*.so')
+        assert len(fns) == 1
+
         subprocess.check_call([
             'install_name_tool', '-change',
                os.path.abspath('lib/libshared.1.dylib'),
                os.path.abspath('lib/libshared.dylib'),
-               'square.so'
+               fns[0]
             ])
 
 setup(
